<?php

namespace Drupal\gleap\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Provides a Gleap block.
 * @Block( id = "gleap_block",
 * admin_label = @Translation("Gleap Block"),
 * category = @Translation("Gleap")
 * )
 */
class GleapBlock extends BlockBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('gleap.gleap_configuration');

    if (empty($config->get('gleap_api_key')) && (\Drupal::currentUser()->hasPermission('administer gleap'))) {
      $url = Url::fromUri('route:gleap_configuration');
      $link = new Link($this->t('here'), $url);
      $link = $link->toString()->getGeneratedLink();
      $script = Markup::create($this->t('Please fill out the Gleap API key from') . " " . $link);
    }
    else {
      $script = Markup::create('<script>!function(Gleap,t,i){if(!(Gleap=window.Gleap=window.Gleap||[]).invoked){for(window.GleapActions=[],Gleap.invoked=!0,Gleap.methods=["identify","clearIdentity","attachCustomData","setCustomData","removeCustomData","clearCustomData","registerCustomAction","logEvent","sendSilentCrashReport","startFeedbackFlow","setAppBuildNumber","setAppVersionCode","preFillForm","setApiUrl","setFrameUrl","isOpened","open","close","on","setLanguage","setOfflineMode","initialize"],Gleap.f=function(e){return function(){var t=Array.prototype.slice.call(arguments);window.GleapActions.push({e:e,a:t})}},t=0;t<Gleap.methods.length;t++)Gleap[i=Gleap.methods[t]]=Gleap.f(i);Gleap.load=function(){var t=document.getElementsByTagName("head")[0],i=document.createElement("script");i.type="text/javascript",i.async=!0,i.src="https://js.gleap.io/latest/index.js",t.appendChild(i)},Gleap.load(), Gleap.initialize("' . $config->get('gleap_api_key') . '") }}();</script>');
    }
    return [
      '#markup' => $script,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() {
    // Return default tags instead.
    return parent::getCacheTags();
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return Cache::mergeContexts(parent::getCacheContexts(), ['route']);
  }

}
